@@ -231,7 +231,7 @@ API_EXPORT(int) ap_hook_configure(char *hook, ap_hook_sig sig, ap_hook_mode mode
 /*
  * Register a function to call for a hook
  */
-API_EXPORT(int) ap_hook_register(char *hook, void *func, void *ctx)
+API_EXPORT(int) ap_hook_register_I(char *hook, void *func, void *ctx)
 {
     int i, j;
     ap_hook_entry *he;
@@ -263,13 +263,12 @@ API_EXPORT(int) ap_hook_register(char *hook, void *func, void *ctx)
 /*
  * Unregister a function to call for a hook
  */
-API_EXPORT(int) ap_hook_unregister(char *hook, void *func)
+API_EXPORT(int) ap_hook_unregister_I(char *hook, void *func)
 {
     int i, j;
     ap_hook_entry *he;
 
-    he = ap_hook_find(hook);
-    if (he == NULL)
+    if ((he = ap_hook_find(hook)) == NULL)
         return FALSE;
     for (i = 0; he->he_func[i] != NULL; i++) {
         if (he->he_func[i]->hf_ptr == func) {
@@ -343,7 +342,9 @@ API_EXPORT(int) ap_hook_use(char *hook, ap_hook_sig sig, ap_hook_mode modeid, ..
         if (ap_hook_call_func(ap, he, he->he_func[i]))
             break;
 
-    if (i == AP_HOOK_MAX_FUNCS || he->he_func[i] == NULL)
+    if (i > 0 && he->he_modeid == AP_HOOK_MODE_ALL)
+        rc = TRUE;
+    else if (i == AP_HOOK_MAX_FUNCS || he->he_func[i] == NULL)
         rc = FALSE;
     else
         rc = TRUE;
@@ -378,7 +379,9 @@ API_EXPORT(int) ap_hook_call(char *hook, ...)
         if (ap_hook_call_func(ap, he, he->he_func[i]))
             break;
 
-    if (i == AP_HOOK_MAX_FUNCS || he->he_func[i] == NULL)
+    if (i > 0 && he->he_modeid == AP_HOOK_MODE_ALL)
+        rc = TRUE;
+    else if (i == AP_HOOK_MAX_FUNCS || he->he_func[i] == NULL)
         rc = FALSE;
     else
         rc = TRUE;
@@ -441,21 +444,21 @@ static int ap_hook_call_func(va_list ap, ap_hook_entry *he, ap_hook_func *hf)
      *
      * 3. Actually currently used hooks.
      *
-     *    int   func(ptr,ptr,int)              ap::buff::read [http_main.c]
-     *    int   func(ptr,ptr,int)              ap::buff::write [http_main.c]
-     *    int   func(ptr,ptr,int)              ap::buff::sendwithtimeout [http_main.c]
-     *    int   func(ptr,ptr,int)              ap::buff::recvwithtimeout [http_main.c]
-     *    int   func(ptr,ptr)                  ap::proxy::canon [mod_proxy.c]
-     *    int   func(ptr,ptr,ptr,int)          ap::proxy::http::canon [mod_proxy.c]
-     *    int   func(ptr,ptr,ptr,ptr,int)      ap::proxy::http::handler [mod_proxy.c]
-     *    int   func(ptr,ptr)                  ap::proxy::error [mod_proxy.c]
-     *    int   func(ptr,ptr,ptr,ptr,int,ptr)  ap::proxy::handler [mod_proxy.c]
-     *    int   func(ptr)                      ap::proxy::http::handler::set_destport [proxy_http.c]
-     *    ptr   func(ptr,ptr)                  ap::proxy::http::handler::new_connection [proxy_http.c]
-     *    int   func(ptr,ptr,ptr,int,ptr)      ap::proxy::http::handler::write_host_header [proxy_http.c]
-     *    ptr   func(ptr,ptr,ptr,ptr,ptr)      ap::mod_ssl::var_lookup [ssl_engine_vars.c]
-     *    ptr   func(ptr,ptr)                  ap::log_config::expand_x_variable [mod_log_config.c]
-     *    ptr   func(char)                     ap::log_config::register_function [mod_log_config.c]
+     *    int   func(ptr,ptr,int)              e.g. ap::buff::read [http_main.c]
+     *    int   func(ptr,ptr,int)              e.g. ap::buff::write [http_main.c]
+     *    int   func(ptr,ptr,int)              e.g. ap::buff::writev [http_main.c]
+     *    int   func(ptr,ptr,int)              e.g. ap::buff::sendwithtimeout [http_main.c]
+     *    int   func(ptr,ptr,int)              e.g. ap::buff::recvwithtimeout [http_main.c]
+     *    int   func(ptr,ptr)                  e.g. ap::mod_proxy::canon [mod_proxy.c]
+     *    int   func(ptr,ptr,ptr,int)          e.g. ap::mod_proxy::http::canon [mod_proxy.c]
+     *    int   func(ptr,ptr,ptr,ptr,int)      e.g. ap::mod_proxy::http::handler [mod_proxy.c]
+     *    int   func(ptr,ptr)                  e.g. ap::mod_proxy::error [mod_proxy.c]
+     *    int   func(ptr,ptr,ptr,ptr,int,ptr)  e.g. ap::mod_proxy::handler [mod_proxy.c]
+     *    int   func(ptr)                      e.g. ap::mod_proxy::http::handler::set_destport [proxy_http.c]
+     *    ptr   func(ptr,ptr)                  e.g. ap::mod_proxy::http::handler::new_connection [proxy_http.c]
+     *    int   func(ptr,ptr,ptr,int,ptr)      e.g. ap::mod_proxy::http::handler::write_host_header [proxy_http.c]
+     *    ptr   func(ptr,ptr,ptr,ptr,ptr)      e.g. ap::mod_ssl::var_lookup [ssl_engine_vars.c]
+     *    ptr   func(ptr,ptr)                  e.g. ap::mod_rewrite::lookup_variable [mod_rewrite.c]
      *
      * To simplify the programming task we generate the actual dispatch code
      * for these calls via the embedded Perl script at the end of this source
@@ -756,7 +759,9 @@ static int ap_hook_call_func(va_list ap, ap_hook_entry *he, ap_hook_func *hf)
     else
         ap_log_assert("hook signature not implemented", __FILE__, __LINE__);
 
-    if (he->he_modeid == AP_HOOK_MODE_TOPMOST)
+    if (he->he_modeid == AP_HOOK_MODE_ALL)
+        rc = FALSE;
+    else if (he->he_modeid == AP_HOOK_MODE_TOPMOST)
         rc = TRUE;
 
     return rc;
@@ -794,7 +799,7 @@ if ($ARGV[0] eq 'used') {
             my ($rc, $args) = ($sig =~ m|^([^,]+)(.*)$|);
             $args =~ s|^,||;
             $src =~ s|^.+/||;
-            printf("     *    %-6s%-30s %s [%s]\n", $rc, "func($args)", $hook, $src);
+            printf("     *    %-6s%-30s e.g. %s [%s]\n", $rc, "func($args)", $hook, $src);
         }
         $source =~ s|\("([^"]+)",\s*AP_HOOK_SIG[0-9]\((.+?)\)|&printme($s, $1, $2), ''|sge;
     }
