@@ -410,14 +410,16 @@ typedef unsigned long int ap_hook_sig;
 /* the type of the return value modes */
 typedef unsigned int ap_hook_mode;
 
-/* the values of the return value mode */
+/* the mode of the return value */
 #define AP_HOOK_MODE_UNKNOWN  0
 #define AP_HOOK_MODE_TOPMOST  1
 #define AP_HOOK_MODE_DECLINE  2
+#define AP_HOOK_MODE_ALL      3
 
 /* the constructors for the return value modes */
 #define AP_HOOK_TOPMOST       AP_HOOK_MODE_TOPMOST
 #define AP_HOOK_DECLINE(val)  AP_HOOK_MODE_DECLINE, (val)   
+#define AP_HOOK_ALL           AP_HOOK_MODE_ALL
 
 /*
  * Hook State Identification
@@ -441,8 +443,8 @@ typedef unsigned short int ap_hook_state;
  *         context value or just the dummy value.
  */
 
-#define AP_HOOK_NOCTX  0
-#define AP_HOOK_CTX(v) (v)
+#define AP_HOOK_NOCTX  (void *)(0)
+#define AP_HOOK_CTX(v) (void *)(v)
 
 /*
  * Internal Hook Record Definition
@@ -513,17 +515,31 @@ typedef struct {
 #define TRUE  !FALSE
 #endif
 
+/*
+ * Wrapper macros for the callback-function register/unregister calls.  
+ * 
+ * Background: Strict ANSI C doesn't allow a function pointer to be treated as
+ * a void pointer on argument passing, but we cannot declare the argument as a
+ * function prototype, because the functions can have arbitrary signatures. So
+ * we have to use a void pointer here. But to not require explicit casts on
+ * function pointers for every register/unregister call, we smooth the API a
+ * little bit by providing these macros.
+ */
+
+#define ap_hook_register(hook,func,ctx) ap_hook_register_I(hook,(void *)(func),ctx)
+#define ap_hook_unregister(hook,func)   ap_hook_unregister_I(hook,(void *)(func))
+
 /*
  * Prototypes for the hook API functions
  */
 
-API_EXPORT(void)          ap_hook_init      (void);
-API_EXPORT(void)          ap_hook_kill      (void);
-API_EXPORT(int)           ap_hook_configure (char *hook, ap_hook_sig sig, ap_hook_mode modeid, ...);
-API_EXPORT(int)           ap_hook_register  (char *hook, void *func, void *ctx);
-API_EXPORT(int)           ap_hook_unregister(char *hook, void *func);
-API_EXPORT(ap_hook_state) ap_hook_status    (char *hook);
-API_EXPORT(int)           ap_hook_use       (char *hook, ap_hook_sig sig, ap_hook_mode modeid, ...);
-API_EXPORT(int)           ap_hook_call      (char *hook, ...);
+API_EXPORT(void)          ap_hook_init         (void);
+API_EXPORT(void)          ap_hook_kill         (void);
+API_EXPORT(int)           ap_hook_configure    (char *hook, ap_hook_sig sig, ap_hook_mode modeid, ...);
+API_EXPORT(int)           ap_hook_register_I   (char *hook, void *func, void *ctx);
+API_EXPORT(int)           ap_hook_unregister_I (char *hook, void *func);
+API_EXPORT(ap_hook_state) ap_hook_status       (char *hook);
+API_EXPORT(int)           ap_hook_use          (char *hook, ap_hook_sig sig, ap_hook_mode modeid, ...);
+API_EXPORT(int)           ap_hook_call         (char *hook, ...);
 
 #endif /* AP_HOOK_H */
