@@ -175,7 +175,7 @@ module MODULE_VAR_EXPORT ssl_module = {
     /* Extended API (forced to be enabled with mod_ssl) */
 
     ssl_hook_AddModule,       /* after modules was added to core     */
-    NULL,                     /* before module is removed from core  */
+    ssl_hook_RemoveModule,    /* before module is removed from core  */
     ssl_hook_RewriteCommand,  /* configuration command rewriting     */
     ssl_hook_NewConnection    /* configuration command rewriting     */
 };
