@@ -222,7 +222,7 @@
  * Support for Mutex
  */
 #ifndef WIN32
-#define SSL_MUTEX_LOCK_MODE ( S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH )
+#define SSL_MUTEX_LOCK_MODE ( S_IRUSR|S_IWUSR )
 #else
 #define SSL_MUTEX_LOCK_MODE (_S_IREAD|_S_IWRITE )
 #endif
@@ -244,7 +244,7 @@
  * Support for DBM library
  */
 #ifndef WIN32
-#define SSL_DBM_FILE_MODE ( S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH )
+#define SSL_DBM_FILE_MODE ( S_IRUSR|S_IWUSR )
 #else
 #define SSL_USE_SDBM
 #define SSL_DBM_FILE_MODE ( _S_IREAD|_S_IWRITE )
@@ -514,6 +514,7 @@ void         ssl_init_Child(server_rec *, pool *);
 
 /*  Apache API hooks  */
 void         ssl_hook_AddModule(module *);
+void         ssl_hook_RemoveModule(module *);
 char        *ssl_hook_RewriteCommand(cmd_parms *, void *config, const char *);
 void         ssl_hook_NewConnection(conn_rec *);
 void         ssl_hook_TimeoutConnection(int);
@@ -586,14 +587,17 @@ void         ssl_die(void);
 
 /*  Variables  */
 void         ssl_var_register(void);
+void         ssl_var_unregister(void);
 char        *ssl_var_lookup(pool *, server_rec *, conn_rec *, request_rec *, char *);
 
 /*  I/O  */
 void         ssl_io_register(void);
+void         ssl_io_unregister(void);
 long         ssl_io_data_cb(BIO *, int, char *, int, long, long);
 
 /*  Extensions  */
 void         ssl_ext_register(void);
+void         ssl_ext_unregister(void);
 
 /*  Compatibility  */
 #ifdef SSL_COMPAT
