@@ -89,6 +89,19 @@ void ssl_hook_AddModule(module *m)
     return;
 }
 
+void ssl_hook_RemoveModule(module *m)
+{
+    if (m == &ssl_module) {
+        /*
+         * Unlink ourself from the Apache kernel
+         */
+        ssl_var_unregister();
+        ssl_ext_unregister();
+        ssl_io_unregister();
+    }
+    return;
+}
+
 void ssl_config_global_create(void)
 {
     pool *pPool;
@@ -269,7 +282,9 @@ const char *ssl_cmd_SSLMutex(
     }
     else if (strlen(arg) > 5 && strcEQn(arg, "file:", 5)) {
         mc->nMutexMode  = SSL_MUTEXMODE_FILE;
-        mc->szMutexFile = ap_server_root_relative(cmd->pool, arg+5);
+        mc->szMutexFile = ap_psprintf(cmd->pool, "%s.%lu",
+                                      ap_server_root_relative(cmd->pool, arg+5), 
+                                      (unsigned long)getpid());
     }
     else if (strcEQ(arg, "sem")) {
 #ifdef SSL_CAN_USE_SEM
