@@ -88,14 +88,30 @@ static int ssl_io_hook_sendwithtimeout(BUFF *fb, const char *buf, int len);
 
 void ssl_io_register(void)
 {
-    ap_hook_register("ap::buff::read",   ssl_io_hook_read,   NULL);
-    ap_hook_register("ap::buff::write",  ssl_io_hook_write,  NULL);
+    ap_hook_register("ap::buff::read",   ssl_io_hook_read,  AP_HOOK_NOCTX);
+    ap_hook_register("ap::buff::write",  ssl_io_hook_write, AP_HOOK_NOCTX);
 #ifndef NO_WRITEV
-    ap_hook_register("ap::buff::writev", ssl_io_hook_writev, NULL);
+    ap_hook_register("ap::buff::writev", ssl_io_hook_writev, AP_HOOK_NOCTX);
 #endif
 #ifdef WIN32
-    ap_hook_register("ap::buff::recvwithtimeout", ssl_io_hook_recvwithtimeout, NULL);
-    ap_hook_register("ap::buff::sendwithtimeout", ssl_io_hook_sendwithtimeout, NULL);
+    ap_hook_register("ap::buff::recvwithtimeout", 
+                     ssl_io_hook_recvwithtimeout, AP_HOOK_NOCTX);
+    ap_hook_register("ap::buff::sendwithtimeout", 
+                     ssl_io_hook_sendwithtimeout, AP_HOOK_NOCTX);
+#endif
+    return;
+}
+
+void ssl_io_unregister(void)
+{
+    ap_hook_unregister("ap::buff::read",   ssl_io_hook_read);
+    ap_hook_unregister("ap::buff::write",  ssl_io_hook_write);
+#ifndef NO_WRITEV
+    ap_hook_unregister("ap::buff::writev", ssl_io_hook_writev);
+#endif
+#ifdef WIN32
+    ap_hook_unregister("ap::buff::recvwithtimeout", ssl_io_hook_recvwithtimeout);
+    ap_hook_unregister("ap::buff::sendwithtimeout", ssl_io_hook_sendwithtimeout);
 #endif
     return;
 }
