@@ -206,10 +206,10 @@ void ssl_hook_NewConnection(conn_rec *conn)
     }
 
     /*
-     * Now do the SSL handshake (or re-negotiation)
+     * Predefine some client verification results
      */
-    ap_ctx_set(fb->ctx, "ssl:clientdn", NULL);
-    ap_ctx_set(fb->ctx, "ssl:verifyerror", NULL);
+    ap_ctx_set(fb->ctx, "ssl::client::dn", NULL);
+    ap_ctx_set(fb->ctx, "ssl::verify::error", NULL);
 
     /* 
      * We have to manage a I/O timeout ourself, because Apache
@@ -341,7 +341,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
         /*
          * Check for failed client authentication
          */
-        if ((cp = (char *)ap_ctx_get(fb->ctx, "ssl:verifyerror")) != NULL) {
+        if ((cp = (char *)ap_ctx_get(fb->ctx, "ssl::verify::error")) != NULL) {
             ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "SSL client authentication failed: %s", cp);
             SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
@@ -362,7 +362,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
             X509 *xs;
             if ((xs = SSL_get_peer_certificate(ssl)) != NULL) {
                 s = X509_NAME_oneline(X509_get_subject_name(xs), NULL, 0);
-                ap_ctx_set(fb->ctx, "ssl:clientdn", ap_pstrdup(conn->pool, s));
+                ap_ctx_set(fb->ctx, "ssl::client::dn", ap_pstrdup(conn->pool, s));
                 free(s);
             }
         }
@@ -372,7 +372,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
          * is required we really got one... (be paranoid)
          */
         if (   sc->nVerifyClient == SSL_CVERIFY_REQUIRE
-            && ap_ctx_get(fb->ctx, "ssl:clientdn") == NULL) {
+            && ap_ctx_get(fb->ctx, "ssl::client::dn") == NULL) {
             ssl_log(srvr, SSL_LOG_ERROR,
                     "No acceptable peer certificate available");
             SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
@@ -517,7 +517,7 @@ int ssl_hook_Auth(request_rec *r)
         return DECLINED;
     if (r->connection->user)
         return DECLINED;
-    if ((clientdn = (char *)ap_ctx_get(r->connection->client->ctx, "ssl:clientdn")) == NULL)
+    if ((clientdn = (char *)ap_ctx_get(r->connection->client->ctx, "ssl:client::dn")) == NULL)
         return DECLINED;
 
     /*
@@ -788,8 +788,8 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
     if (!ok) {
         ssl_log(s, SSL_LOG_ERROR, "Certificate Verification: Error (%d): %s",
                 errnum, X509_verify_cert_error_string(errnum));
-        ap_ctx_set(conn->client->ctx, "ssl:clientdn", NULL);
-        ap_ctx_set(conn->client->ctx, "ssl:verifyerror",
+        ap_ctx_set(conn->client->ctx, "ssl::client::dn", NULL);
+        ap_ctx_set(conn->client->ctx, "ssl::verify::error",
                    X509_verify_cert_error_string(errnum));
     }
 
@@ -799,7 +799,7 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
     if (errdepth > sc->nVerifyDepth) {
         ssl_log(s, SSL_LOG_ERROR,
                 "Certificate Verification: Certificate Chain too long");
-        ap_ctx_set(conn->client->ctx, "ssl:verifyerror",
+        ap_ctx_set(conn->client->ctx, "ssl::verify::error",
                    X509_verify_cert_error_string(X509_V_ERR_CERT_CHAIN_TOO_LONG));
         ok = FALSE;
     }
