@@ -92,6 +92,12 @@ void ssl_var_register(void)
     return;
 }
 
+void ssl_var_unregister(void)
+{
+    ap_hook_unregister("ap::mod_ssl::var_lookup", ssl_var_lookup);
+    return;
+}
+
 char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *var)
 {
     SSLModConfigRec *mc = myModConfig();
@@ -140,6 +146,8 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
             result = r->the_request;
         else if (strcEQ(var, "REQUEST_METHOD"))
             result = r->method;
+        else if (strcEQ(var, "REQUEST_SCHEME"))
+            result = ap_http_method(r);
         else if (strcEQ(var, "REQUEST_URI"))
             result = r->uri;
         else if (strcEQ(var, "SCRIPT_FILENAME") ||
