@@ -116,6 +116,27 @@
 **  _________________________________________________________________
 */
 
+char *ssl_util_vhostid(pool *p, server_rec *s)
+{
+    char *id;
+    SSLSrvConfigRec *sc;
+    char *host;
+    int port;
+    
+    host = s->server_hostname;
+    if (s->port != 0)
+        port = s->port;
+    else {
+        sc = mySrvConfig(s);
+        if (sc->bEnabled)
+            port = DEFAULT_HTTPS_PORT;
+        else
+            port = DEFAULT_HTTP_PORT;
+    }
+    id = ap_psprintf(p, "%s:%d", host, port);
+    return id;
+}
+
 void ssl_util_strupper(char *s)
 {
     for (; *s; ++s)
